pub struct Bm8563<I2C> { /* private fields */ }Implementations
Sourceimpl<I2C, Error> Bm8563<I2C>where
I2C: I2c<Error = Error>,
impl<I2C, Error> Bm8563<I2C>where
I2C: I2c<Error = Error>,
pub fn init(&mut self) -> Result<(), Error>
pub fn datetime(&mut self) -> Result<DateTime, Error>
Sourcepub fn clock_integrity_lost(&mut self) -> Result<bool, Error>
pub fn clock_integrity_lost(&mut self) -> Result<bool, Error>
Returns true when BM8563 reports low voltage or clock-integrity loss.
BM8563 stores this in bit 7 of the seconds register. When set, the date and time should be treated as potentially invalid until application code sets a known-good time.
pub fn set_datetime(&mut self, datetime: DateTime) -> Result<(), Error>
pub fn set_alarm(&mut self, alarm: Alarm) -> Result<(), Error>
pub fn set_timer(&mut self, timer: TimerConfig) -> Result<(), Error>